<?php

/**
 * @file
 * General page callbacks for the bugbits module.
 */

/**
 * Page callback: provides a list of issues for the given project
 *
 * @param $projectId the mantis project id
 * @return themed html output
 */
function bugbits_project_issues($projectId){
  // TODO: Need to somehow get a count of the issues plus get the name of the project.
  module_load_include('inc', 'bugbits', 'includes/mantisProject');
  $page = (isset($_GET['page']) && is_numeric($_GET['page']))? check_plain($_GET['page']) : 0;
  $limit = (isset($_GET['limit']) && is_numeric($_GET['limit']))? check_plain($_GET['limit']) : 10;
  $issues = mantisProject::getIssues($projectId, $page, $limit);
  $issueCount = mantisProject::getIssueCount($projectId);
  return theme('bugbits_project_issue', $issues, $issueCount, $limit, $page);  
}

/**
 * Page callback: provides the form to add an issue
 *
 * @param $projectId the mantis project id
 * @ingroup form
 */
function bugbits_project_issue_add(&$form_state, $project_id = 0) {
  module_load_include('inc', 'bugbits', 'includes/mantisProject');
  module_load_include('inc', 'bugbits', 'includes/mantisEnum');
  $form = array();
  
  $categories = mantisProject::getCategories($project_id);
  $options_cat = array(0 => '(select)');
  $i = 1;
  foreach ($categories as $category_name) {
    $options_cat[$i] = $category_name;
    $i++;
  }
  $form['category'] = array(
    '#type' => 'select',
    '#title' => t('Category'),
    '#required' => TRUE,
    '#options' => $options_cat,
  );
  
  $reproducibilities = mantisEnum::enumReproducibilities();
  foreach ($reproducibilities as $reproducibility) {
    $options_rep[$reproducibility->id] = $reproducibility->name;
  }
  $form['reproducibilities'] = array(
    '#type' => 'select',
    '#title' => t('Reproducibility'),
    '#options' => $options_rep,
    '#default_value' => 70,
  );
  
  $severities = mantisEnum::enumSeverities();
  foreach ($severities as $severity) {
    $options_sev[$severity->id] = $severity->name;
  }
  $form['severity'] = array(
    '#type' => 'select',
    '#title' => t('Severity'),
    '#options' => $options_sev,
    '#default_value' => 50,
  );
  
  $priorities = mantisEnum::enumPriorities();
  foreach ($priorities as $priority) {
    $options_prio[$priority->id] = $priority->name;
  }
  $form['priority'] = array(
    '#type' => 'select',
    '#title' => t('Priority'),
    '#options' => $options_prio,
    '#default_value' => 30,
  );
  
  // Profile: not able to fetch list
  
  // Assigned: not able to fetch list
  
  
  $form['summary'] = array(
    '#type' => 'textfield',
    '#title' => t('Summary'),
    '#size' => 105,
    '#maxlength' => 128,
    '#required' => TRUE,
  );
  
  $form['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#cols' => 80,
    '#rows' => 10,
    '#required' => TRUE,
  );
  
  $form['steps_reproduce'] = array(
    '#type' => 'textarea',
    '#title' => t('Steps to reproduce'),
    '#cols' => 80,
    '#rows' => 10,
  );
  
  $form['#attributes'] = array('enctype' => "multipart/form-data");
  $form['attachment'] = array(
    '#type' => 'file',
    '#title' => t('Upload file'),
  );
  
  $view_states = mantisEnum::enumViewStates();
  foreach ($view_states as $view_state) {
    $options_view[$view_state->id] = $view_state->name;
  }
  $form['view_status'] = array(
    '#type' => 'radios',
    '#title' => t('View status'),
    '#options' => $options_view,
    '#default_value' => 10,
  );
  
  $form['submit'] = array(
    '#type' => 'submit', 
    '#value' => t('Submit report'),
  );
  
  return $form;
}

/**
 * Page callback: Provides information for a particular issue
 *
 * @param $issueId the mantis issue id
 * @return themed html output
 */
function bugbits_issue($issueId){
  module_load_include('inc', 'bugbits', 'includes/mantisIssue');  
  $issue = mantisIssue::get($issueId);
  if($issue){
    drupal_set_title($issue->summary);
    $output = theme('bugbits_issue', $issue);
  }else{
    drupal_set_title('Issue not found');
    $output = '<p>Issue not found</p>';
  }
  return $output;
}